@@ -280,6 +280,7 @@ def create_app() -> FastAPI:
         term: str = Query(..., description="Term (winter, summer, fall)"),
         year: int = Query(..., description="Year (e.g., 2025)"),
         subjects: str = Query(..., description="Comma-separated list of subject codes (e.g., COMP,MATH)"),
+        course_codes: Optional[str] = Query(None, description="Filter by specific course codes (e.g., COMP1001,MATH1007)"),
         limit: int = Query(10, description="Maximum courses per subject", ge=1, le=50),
         include_ratings: bool = Query(False, description="Include Rate My Professor ratings for instructors")
     ):
@@ -339,6 +340,17 @@ def create_app() -> FastAPI:
                 term_code, subjects=subject_list, max_courses_per_subject=limit
             )
             
+            # Filter by specific course codes if provided
+            if course_codes:
+                requested_codes = [code.strip().upper().replace(' ', '') for code in course_codes.split(',')]
+                filtered_courses = []
+                for course in courses:
+                    # Normalize course code for comparison (remove spaces)
+                    normalized_course_code = course.course_code.upper().replace(' ', '')
+                    if normalized_course_code in requested_codes:
+                        filtered_courses.append(course)
+                courses = filtered_courses
+            
             # Convert to API models
             live_courses = []
             
